==> moengagesdk-4.1.03-sources.jar: com/moengage/core/remoteconfig/RemoteConfigResponseHandler.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.core.remoteconfig;

import android.content.Context;
import android.support.annotation.Nullable;
import com.moengage.core.Logger;
import com.moengage.core.MoEDAO;
import com.moengage.core.MoEUtils;
import com.moengage.core.RemoteConfig;
import com.moengage.core.rest.Response;

/**
 * @author Umang Chamaria
 */
class RemoteConfigResponseHandler {

  private static final String TAG = "RemoteConfigResponseHandler";

  private RemoteConfigResponseParser responseParser;

  RemoteConfigResponseHandler() {
    responseParser = new RemoteConfigResponseParser();
  }

  boolean handleConfigApiResponse(Context context, @Nullable Response response) {
    try {
      if (response == null) {
        Logger.e(TAG + " handleConfigApiResponse() : response object is null.");
        return false;
      }
      if (response.responseCode != 200) {
        Logger.e(TAG
            + " handleConfigApiResponse() : Network Request failed, error: "
            + response.errorMessage);
        return false;
      }
      if (MoEUtils.isEmptyString(response.responseBody)) return false;
      //update remote configuration
      RemoteConfig remoteConfig = responseParser.parseConfigApiResponse(response);
      if (remoteConfig != null) {
        MoEDAO.getInstance(context).addOrUpdateRemoteConfiguration(response.responseBody);
        RemoteConfig.setRemoteConfig(remoteConfig);
      }
      //update last sync time
      MoEDAO.getInstance(context).updateConfigApiSyncTime(MoEUtils.currentTime());
      return true;
    } catch (Exception e) {
      Logger.e(TAG + " handleConfigApiResponse() : ");
    }
    return false;
  }
}

==> moengagesdk-4.2.00-sources.jar: com/moengage/core/remoteconfig/RemoteConfigResponseHandler.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.core.remoteconfig;

import android.content.Context;
import androidx.annotation.Nullable;
import com.moengage.core.Logger;
import com.moengage.core.MoEConstants;
import com.moengage.core.MoEDAO;
import com.moengage.core.MoEUtils;
import com.moengage.core.RemoteConfig;
import com.moengage.core.rest.Response;

/**
 * @author Umang Chamaria
 */
class RemoteConfigResponseHandler {

  private static final String TAG = MoEConstants.MODULE_TAG + "RemoteConfigResponseHandler";

  private RemoteConfigResponseParser responseParser;

  RemoteConfigResponseHandler() {
    responseParser = new RemoteConfigResponseParser();
  }

  boolean handleConfigApiResponse(Context context, @Nullable Response response) {
    try {
      if (response == null) {
        Logger.e(TAG + " handleConfigApiResponse() : response object is null.");
        return false;
      }
      if (response.responseCode != 200) {
        Logger.e(TAG
            + " handleConfigApiResponse() : Network Request failed, error: "
            + response.errorMessage);
        return false;
      }
      if (MoEUtils.isEmptyString(response.responseBody)) return false;
      //update remote configuration
      RemoteConfig remoteConfig = responseParser.parseConfigApiResponse(response);
      if (remoteConfig != null) {
        MoEDAO.getInstance(context).addOrUpdateRemoteConfiguration(response.responseBody);
        RemoteConfig.setRemoteConfig(remoteConfig);
      }
      //update last sync time
      MoEDAO.getInstance(context).updateConfigApiSyncTime(MoEUtils.currentMillis());
      return true;
    } catch (Exception e) {
      Logger.e(TAG + " handleConfigApiResponse() : ");
    }
    return false;
  }
}
